summaryrefslogtreecommitdiff
path: root/src/mongo/db/storage/storage_engine.h
diff options
context:
space:
mode:
authorGregory Wlodarek <gregory.wlodarek@mongodb.com>2019-01-04 12:02:53 -0500
committerGregory Wlodarek <gregory.wlodarek@mongodb.com>2019-01-04 12:02:53 -0500
commite4fe8b89a9ce01a3571114e9c51a4cdd725fbe1d (patch)
tree95225bc94c71e2f9439fd47cd3110fbc58f5a959 /src/mongo/db/storage/storage_engine.h
parentf11fb53bfd42ee53857d263407d9e555b9a1140a (diff)
downloadmongo-e4fe8b89a9ce01a3571114e9c51a4cdd725fbe1d.tar.gz
Revert "SERVER-38527 Merge supportsRecoverToStableTimestamp into supportsRecoveryTimestamp"
This reverts commit 804617152c5b4f89c8d54c83bdea90cb2c8541b4.
Diffstat (limited to 'src/mongo/db/storage/storage_engine.h')
-rw-r--r--src/mongo/db/storage/storage_engine.h21
1 files changed, 14 insertions, 7 deletions
diff --git a/src/mongo/db/storage/storage_engine.h b/src/mongo/db/storage/storage_engine.h
index 746f48a8078..f281efd0290 100644
--- a/src/mongo/db/storage/storage_engine.h
+++ b/src/mongo/db/storage/storage_engine.h
@@ -327,10 +327,17 @@ public:
virtual void setJournalListener(JournalListener* jl) = 0;
/**
- * Returns whether the storage engine can provide a timestamp that can be used for recovering
- * to a stable timestamp. If the storage engine supports "recover to stable timestamp" but does
- * not currently have a stable timestamp, then StorageEngine::recoverToStableTimestamp() will
- * return a bad status.
+ * Returns whether the storage engine supports "recover to stable timestamp". Returns true
+ * if the storage engine supports "recover to stable timestamp" but does not currently have
+ * a stable timestamp. In that case StorageEngine::recoverToStableTimestamp() will return
+ * a bad status.
+ */
+ virtual bool supportsRecoverToStableTimestamp() const {
+ return false;
+ }
+
+ /**
+ * Returns whether the storage engine can provide a recovery timestamp.
*/
virtual bool supportsRecoveryTimestamp() const {
return false;
@@ -370,7 +377,7 @@ public:
*
* If successful, returns the timestamp that the storage engine recovered to.
*
* fasserts if StorageEngine::supportsRecoveryTimestamp() would return
* false. Returns a bad status if there is no stable timestamp to recover to.
*
* It is illegal to call this concurrently with `setStableTimestamp` or
@@ -383,7 +390,7 @@ public:
/**
* Returns the stable timestamp that the storage engine recovered to on startup. If the
* recovery point was not stable, returns "none".
* fasserts if StorageEngine::supportsRecoveryTimestamp() would return false.
*/
virtual boost::optional<Timestamp> getRecoveryTimestamp() const {
MONGO_UNREACHABLE;
@@ -395,7 +402,7 @@ public:
* durable engines, it is also the guaranteed minimum stable recovery point on server restart
* after crash or shutdown.
*
* fasserts if StorageEngine::supportsRecoveryTimestamp() would return false. Returns
* boost::none if the recovery time has not yet been established. Replication recoverable
* rollback may not succeed before establishment, and restart will require resync.
*/
@@ -370,7 +377,7 @@ public:
* If successful, returns the timestamp that the storage engine recovered to.
*
- * fasserts if StorageEngine::supportsRecoveryTimestamp() would return
+ * fasserts if StorageEngine::supportsRecoverToStableTimestamp() would return
* false. Returns a bad status if there is no stable timestamp to recover to.
*
@@ -383,7 +390,7 @@ public:
* Returns the stable timestamp that the storage engine recovered to on startup. If the
* recovery point was not stable, returns "none".
- * fasserts if StorageEngine::supportsRecoveryTimestamp() would return false.
+ * fasserts if StorageEngine::supportsRecoverToStableTimestamp() would return false.
*/
virtual boost::optional<Timestamp> getRecoveryTimestamp() const {
@@ -395,7 +402,7 @@ public:
* after crash or shutdown.
*
- * fasserts if StorageEngine::supportsRecoveryTimestamp() would return false. Returns
+ * fasserts if StorageEngine::supportsRecoverToStableTimestamp() would return false. Returns
* boost::none if the recovery time has not yet been established. Replication recoverable
* rollback may not succeed before establishment, and restart will require resync.